summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopeteemoticonaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/kopeteemoticonaction.h')
-rw-r--r--kopete/kopete/chatwindow/kopeteemoticonaction.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/kopete/chatwindow/kopeteemoticonaction.h b/kopete/kopete/chatwindow/kopeteemoticonaction.h
index 7ae3291c..a76dcb0c 100644
--- a/kopete/kopete/chatwindow/kopeteemoticonaction.h
+++ b/kopete/kopete/chatwindow/kopeteemoticonaction.h
@@ -32,7 +32,7 @@ class KopeteEmoticonAction : public KAction
TQ_PROPERTY( bool stickyMenu READ stickyMenu WRITE setStickyMenu )
public:
- KopeteEmoticonAction( TQObject *tqparent = 0, const char *name = 0 );
+ KopeteEmoticonAction( TQObject *parent = 0, const char *name = 0 );
virtual ~KopeteEmoticonAction();
KPopupMenu * popupMenu() const;
@@ -53,7 +53,7 @@ public:
* cannot be clicked, then you should call setDelayed(false).
*
* On the opposite, if the main action can be clicked, it can only happen
* in a toolbar: in a menu, the tqparent of a submenu can't be activated.
* To get a "normal" menu item when plugged a menu (and no submenu)
* use KToolBarPopupAction.
*/
@@ -53,7 +53,7 @@ public:
*
* On the opposite, if the main action can be clicked, it can only happen
- * in a toolbar: in a menu, the tqparent of a submenu can't be activated.
+ * in a toolbar: in a menu, the parent of a submenu can't be activated.
* To get a "normal" menu item when plugged a menu (and no submenu)
* use KToolBarPopupAction.